==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebGroupByRecordDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebGroupByRecordDescription } from "./WebGroupByRecordDescription";
/**
 * @hidden
 */
var WebGroupByRecordDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGroupByRecordDescriptionMetadata, _super);
    function WebGroupByRecordDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByRecordDescriptionMetadata.b = function (a) {
        if (WebGroupByRecordDescriptionMetadata.a == null) {
            WebGroupByRecordDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByRecordDescriptionMetadata.c(WebGroupByRecordDescriptionMetadata.a);
        }
        if (a.j(WebGroupByRecordDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGroupByRecordDescriptionMetadata.a);
        WebSortingExpressionDescriptionMetadata.d(a);
        WebGroupByRecordDescriptionMetadata.d(a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebGroupByRecordDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByRecord");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Expression", "ExportedType:WebSortingExpression");
        a.item("Level", "Number:double");
        a.item("RecordsRef", "(w:Records,wf:Records)DataRef:object");
        a.item("Value", "Unknown");
        a.item("GroupParent", "ExportedType:WebGroupByRecord");
        a.item("Groups", "Array:WebGroupByRecordDescription:GroupByRecord");
        a.item("Height", "Number:double");
        a.item("Column", "ExportedType:WebColumn");
    };
    WebGroupByRecordDescriptionMetadata.d = function (a) {
        WebGroupByRecordDescriptionMetadata.b(a);
        a.aa("WebGroupByRecord", function () { return new WebGroupByRecordDescription(); });
        a.z("WebGroupByRecord", WebGroupByRecordDescriptionMetadata.a);
    };
    WebGroupByRecordDescriptionMetadata.$t = markType(WebGroupByRecordDescriptionMetadata, 'WebGroupByRecordDescriptionMetadata');
    WebGroupByRecordDescriptionMetadata.a = null;
    return WebGroupByRecordDescriptionMetadata;
}(Base));
export { WebGroupByRecordDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGroupByRecordDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebGroupByRecordDescription } from "./WebGroupByRecordDescription";
/**
 * @hidden
 */
var WebGroupByRecordDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGroupByRecordDescriptionMetadata, _super);
    function WebGroupByRecordDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByRecordDescriptionMetadata.b = function (a) {
        if (WebGroupByRecordDescriptionMetadata.a == null) {
            WebGroupByRecordDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByRecordDescriptionMetadata.c(WebGroupByRecordDescriptionMetadata.a);
        }
        if (a.k(WebGroupByRecordDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGroupByRecordDescriptionMetadata.a);
        WebSortingExpressionDescriptionMetadata.d(a);
        WebGroupByRecordDescriptionMetadata.d(a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebGroupByRecordDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByRecord");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Expression", "ExportedType:WebSortingExpression");
        a.item("Level", "Number:double");
        a.item("RecordsRef", "(w:Records,wf:Records)DataRef:object");
        a.item("Value", "Unknown");
        a.item("GroupParent", "ExportedType:WebGroupByRecord");
        a.item("Groups", "Array:WebGroupByRecordDescription:GroupByRecord");
        a.item("Height", "Number:double");
        a.item("Column", "ExportedType:WebColumn");
    };
    WebGroupByRecordDescriptionMetadata.d = function (a) {
        WebGroupByRecordDescriptionMetadata.b(a);
        a.ac("WebGroupByRecord", function () { return new WebGroupByRecordDescription(); });
        a.ab("WebGroupByRecord", WebGroupByRecordDescriptionMetadata.a);
    };
    WebGroupByRecordDescriptionMetadata.$t = markType(WebGroupByRecordDescriptionMetadata, 'WebGroupByRecordDescriptionMetadata');
    WebGroupByRecordDescriptionMetadata.a = null;
    return WebGroupByRecordDescriptionMetadata;
}(Base));
export { WebGroupByRecordDescriptionMetadata };
